@@ -307,15 +307,11 @@ class APIRequestor(object):
         # Use a CA_BUNDLE containing the following chain:
         # - TrustedRoot
         # - DigiCert High Assurance EV - 1
-        # - Clever.com EV
         #
         # This ensures that only this certificate chain is used to verify SSL certs.
         # Certs dervived from other ca certs will be treated as invalid.
         # eg. https://api.twitter.com and https://api.stripe.com FAIL
         #     https://api.clever.com and https://api.github.com PASS
-        #
-        # TODO: This gets us close to CERT PINNING but we need to pin the entire
-        # chain not just the CA
         result = requests.request(meth, abs_url,
                                   headers=headers, data=data, timeout=80,
                                   verify=CLEVER_CERTS)
@@ -564,10 +560,10 @@ class CleverObject(object):
     setattr(self, k, v)
 
   def keys(self):
-    return self._values.keys()
+    return self._values
 
   def values(self):
-    return self._values.keys()
+    return self._values
 
   @classmethod
   def construct_from(cls, values, auth):
@@ -731,7 +727,7 @@ class UpdateableAPIResource(APIResource):
       for k in self._unsaved_values:
         params[k] = getattr(self, k)
       url = self.instance_url()
-      response, auth = requestor.request('put', url, params)
+      response, auth = requestor.request('patch', url, params)
       self.refresh_from(response['data'], auth)
     else:
       logger.debug("Trying to save already saved object %r" % (self, ))
